@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11563 2019-05-20 02:06:32Z Lavender $
+# $Id: __init__.py 11609 2019-06-04 18:15:07Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-05-20 11:06:32 +0900 (週一, 20 五月 2019) $
-# $Revision: 11563 $
+# $Date: 2019-06-05 03:15:07 +0900 (週三, 05 六月 2019) $
+# $Revision: 11609 $
 
 import os
 import sys
@@ -474,6 +474,7 @@ def attachShopURLs(settings, urlpatterns):
         # we are not used.
         url(r'^i18n/', include('django.conf.urls.i18n')),
         url(r'^shop/', shop.urls),
+        url(r'^basket/freeze/', views.freezeBasket, name="freezeBasket"),
     )
     
     ckeditorEnable = False
@@ -910,8 +911,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
             
             "GoodsAmount": int(total),
             "CollectionAmount": int(total),
-            "GoodsName": itemName.replace(
-                "#", ' ').replace("(", '').replace(")", '').decode('utf8'),
+           
             
             # 必須 len(SendName) <= 10 個字元 
             "SenderName": shopName,
@@ -925,11 +925,24 @@ def buildAPIForm(submission, request, apiName, extra={}):
             "ClientReplyURL": returnUrl, 
         }
         
+        if six.PY3:
+            data["GoodsName"] = itemName.replace(
+                "#".encode(), ' '.encode()).replace(
+                "(".encode(), ''.encode()).replace(
+                ")".encode(), ''.encode()).decode('utf8')
+        else:
+            data["GoodsName"] = itemName.replace(
+                "#", ' ').replace("(", '').replace(")", '').decode('utf8')
+            
         if mapData['storeType'] == "UNIMARTC2C":
             data["LogisticsC2CReplyURL"] = returnUrl
         
         data = OrderedDict(data)
-        data = OrderedDict(sorted(data.iteritems()))
+        
+        if six.PY3:
+            data = OrderedDict(sorted(data.items()))
+        else:
+            data = OrderedDict(sorted(data.iteritems()))
 
         orderedDict = OrderedDict()
         orderedDict['HashKey'] = settings.ECPAY_API_HASH_KEY
@@ -943,8 +956,13 @@ def buildAPIForm(submission, request, apiName, extra={}):
             dataList.append("%s=%s" % (k, v))
         dataStr = u"&".join(dataList)
 
-        encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
-        checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
+        if six.PY3:
+            encodeStr = urllib.parse.urlencode({'data': utf8(dataStr),})[5:]
+            checkValue = hashlib.md5(
+                encodeStr.lower().encode()).hexdigest().upper()
+        else:
+            encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
+            checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
         data["CheckMacValue"] = checkValue
 
         temp = get_template('shop/payment/EcpayLogistic.html')
