@@ -64,3 +64,33 @@ class CathaybkCreditTrade(models.Model):
     rtnCode = models.CharField(max_length=30) # AUTHSTATUS
     rtnMsg = models.CharField(max_length=30) # AUTHMSG
     cardNo = models.CharField(max_length=30) # CARDNO
+
+class ECPayLogisticTrade(models.Model):
+    # B2C & C2C
+    merchantId = models.CharField(max_length=30) # MerchantID
+    merchantTradeNo = models.CharField(max_length=30) # MerchantTradeNo
+    tradeNo = models.CharField(max_length=30) # AllPayLogisticsID
+    
+    tradeDate = models.DateTimeField()
+    updateStatusDate = models.DateTimeField() # UpdateStatusDate
+    
+    tradeAmt = models.IntegerField() # GoodsAmount
+         
+    rtnCode = models.CharField(max_length=30) # RtnCode
+    rtnMsg = models.CharField(max_length=30) # RtnMsg
+
+    receiverName = models.CharField(max_length=30) # ReceiverName
+    receiverCellPhone = models.CharField(max_length=30) # ReceiverCellPhone
+    receiverEmail = models.CharField(max_length=200, null=True) # ReceiverEmail
+
+    logisticsType = models.CharField(max_length=30) # LogisticsType
+    logisticsSubType = models.CharField(max_length=30) # LogisticsSubType
+
+    # return
+    rtnMerchantTradeNo = models.CharField(max_length=30, null=True)
+    rtnOrderNo = models.CharField(max_length=30, null=True)
+
+    # CVS C2C
+    paymentNo = models.CharField(max_length=30, null=True) # CVSPaymentNo 
+    validationNo = models.CharField(max_length=30, null=True) # CVSValidationNo 
+    
