@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: views.py 11609 2019-06-04 18:15:07Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-17 02:20:57 +0800 (週三, 17 四月 2019) $
-# $Revision: 11459 $ 
+# $Date: 2019-06-05 03:15:07 +0900 (週三, 05 六月 2019) $
+# $Revision: 11609 $ 
 
 import json
 import logging
@@ -36,7 +36,7 @@ from django.contrib import messages
 from django.views import generic
 from django.utils.translation import ugettext as _
 from django.conf import settings
-from django.http import HttpResponse, Http404
+from django.http import HttpResponse, Http404, HttpResponseRedirect
 from django.utils import timezone
 from django.template.loader import get_template
 from django.template import Context
@@ -61,6 +61,12 @@ Source = get_model('payment', 'Source')
 SourceType = get_model('payment', 'SourceType')
 Basket = get_model('basket', 'Basket')
 Order = get_model('order', 'Order')
+Selector = get_class('partner.strategy', 'Selector')
+try:
+    Applicator = get_class('offer.applicator', 'Applicator')
+except ModuleNotFoundError:
+    # fallback for django-oscar<=1.1
+    Applicator = get_class('offer.utils', 'Applicator')
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -409,6 +415,15 @@ def returnCathaybkCreditXml(request):
         rtXml = temp.render(context)
 
         return HttpResponse(rtXml)
+        
+@csrf_exempt       
+def freezeBasket(request):
+    if request.method == 'POST':
+        request.session['preBasketId'] = request.basket.id
+        request.basket.freeze()
+        return HttpResponse("SUCCESS")
+    else:
+        return HttpResponse("ERROR")
 
 class SuccessResponseView2(_PaymentDetailsView):
     preview = True
@@ -419,6 +434,26 @@ class SuccessResponseView2(_PaymentDetailsView):
         self.apiName = kwargs['name']
         return super(SuccessResponseView2, self).dispatch(request, 
                                                          *args, **kwargs)
+                                                         
+    @property
+    def pre_conditions(self):
+        return []
+        
+    def load_frozen_basket(self, basket_id):
+        # Lookup the frozen basket that this txn corresponds to
+        try:
+            basket = Basket.objects.get(id=basket_id, status=Basket.FROZEN)
+        except Basket.DoesNotExist:
+            return None
+
+        # Assign strategy to basket instance
+        if Selector:
+            basket.strategy = Selector().strategy(self.request)
+
+        # Re-apply any offers
+        Applicator().apply(basket, self.request.user, request=self.request)
+
+        return basket
 
     def get_pre_conditions(self, request):
         conditions = super(
@@ -752,6 +787,7 @@ class SuccessResponseView2(_PaymentDetailsView):
                 }
                 return render(
                     request, 'shop/payment/LogisticRedirect.html', ctx)
+                    
             return self.handle_place_order_submission(request)
         except Exception as e:
             # return msg
@@ -832,6 +868,14 @@ class SuccessResponseView2(_PaymentDetailsView):
         
         
     def build_submission(self, **kwargs):
+        errorMsg = _(
+            "A problem occurred communicating with PayPal "
+            "- please try again later"
+        )
+        kwargs['basket'] = self.load_frozen_basket(self.basketId)
+        if not kwargs['basket']:
+            messages.error(self.request, errorMsg)
+            
         submission = super(
             SuccessResponseView2, self).build_submission(**kwargs)
         
