@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: LocalTest.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: LocalTest.py 11534 2019-05-10 09:33:43Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2018-07-16 17:31:00 +0800 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Author: Andy $ (last)
+# $Date: 2019-05-10 18:33:43 +0900 (週五, 10 五月 2019) $
+# $Revision: 11534 $
 
 from Iuppiter import test as TestUtil
 
@@ -62,7 +62,7 @@ class LocalTest(unittest.TestCase):
         self.assertEqual(settings['BROKER_URL'], 
                          'amqp://test:test@naga.servehttp.com:5672/')
         self.assertEqual(settings['CELERY_RESULT_BACKEND'], 
-                         'redis://:25025529@naga.servehttp.com:25025529')
+                         'redis://:25025529@naga.servehttp.com:6379')
 
     def testByConfig(self):
         """
@@ -86,7 +86,7 @@ class LocalTest(unittest.TestCase):
         self.assertEqual(settings['BROKER_URL'], 
                          'amqp://test:test@127.0.0.1:5672/')
         self.assertEqual(settings['CELERY_RESULT_BACKEND'], 
-                         'redis://:redis@127.0.0.1:redis')
+                         'redis://:redis@127.0.0.1:6379')
 
 if __name__ == "__main__":
     unittest.main()
